# PyMISPGalaxies

[![Build Status](https://travis-ci.org/MISP/PyMISPGalaxies.svg?branch=master)](https://travis-ci.org/MISP/PyMISPGalaxies)
[![codecov.io](https://codecov.io/github/MISP/PyMISPGalaxies/coverage.svg?branch=master)](https://codecov.io/github/MISP/PyMISPGalaxies?branch=master)

Pythonic way to work with the galaxies defined there: https://github.com/MISP/misp-galaxy

# Usage

Clusters and Galaxies are represented as immutable Python dictionaries.

